==> rh-quarkus-2.2.3-src.zip: rh-quarkus-2.2.3.GA-src/io.quarkus-quarkus-parent-2.2.3/extensions/qute/deployment/src/test/java/io/quarkus/qute/deployment/i18n/NestedMessageBundleDevModeTest.java <==
package io.quarkus.qute.deployment.i18n;

import static org.junit.jupiter.api.Assertions.assertEquals;

import javax.enterprise.event.Observes;

import org.jboss.shrinkwrap.api.ShrinkWrap;
import org.jboss.shrinkwrap.api.spec.JavaArchive;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.RegisterExtension;

import io.quarkus.qute.i18n.Message;
import io.quarkus.qute.i18n.MessageBundle;
import io.quarkus.qute.i18n.MessageBundles;
import io.quarkus.test.QuarkusDevModeTest;
import io.restassured.RestAssured;
import io.vertx.ext.web.Router;

public class NestedMessageBundleDevModeTest {

    @RegisterExtension
    static final QuarkusDevModeTest testConfig = new QuarkusDevModeTest()
            .setArchiveProducer(() -> ShrinkWrap.create(JavaArchive.class)
                    .addClasses(MyNestedMessages.class, TestRouteConfig.class));

    @Test
    public void testMessages() {
        assertEquals("Hello Jachym!", RestAssured.get("test").then().statusCode(200).extract().body().asString());
        testConfig.modifySourceFile(NestedMessageBundleDevModeTest.class, s -> s.replace("Hello {name}!", "Hi {name}!"));
        assertEquals("Hi Jachym!", RestAssured.get("test").then().statusCode(200).extract().body().asString());
    }

    @MessageBundle
    public interface MyNestedMessages {

        @Message("Hello {name}!")
        String hello_name(String name);

    }

    public static class TestRouteConfig {

        void addTestRoute(@Observes Router router) {
            router.route("/test")
                    .produces("text/plain")
                    .handler(rc -> rc.response().end(MessageBundles.get(MyNestedMessages.class).hello_name("Jachym")));
        }

    }

}

==> rh-quarkus-2.7.5-src.zip: rh-quarkus-2.7.5.GA-src/io.quarkus-quarkus-parent-2.7.5/extensions/qute/deployment/src/test/java/io/quarkus/qute/deployment/i18n/NestedMessageBundleDevModeTest.java <==
package io.quarkus.qute.deployment.i18n;

import static org.junit.jupiter.api.Assertions.assertEquals;

import javax.enterprise.event.Observes;

import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.RegisterExtension;

import io.quarkus.qute.i18n.Message;
import io.quarkus.qute.i18n.MessageBundle;
import io.quarkus.qute.i18n.MessageBundles;
import io.quarkus.test.QuarkusDevModeTest;
import io.restassured.RestAssured;
import io.vertx.ext.web.Router;

public class NestedMessageBundleDevModeTest {

    @RegisterExtension
    static final QuarkusDevModeTest testConfig = new QuarkusDevModeTest()
            .withApplicationRoot((jar) -> jar
                    .addClasses(MyNestedMessages.class, TestRouteConfig.class));

    @Test
    public void testMessages() {
        assertEquals("Hello Jachym!", RestAssured.get("test").then().statusCode(200).extract().body().asString());
        testConfig.modifySourceFile(NestedMessageBundleDevModeTest.class, s -> s.replace("Hello {name}!", "Hi {name}!"));
        assertEquals("Hi Jachym!", RestAssured.get("test").then().statusCode(200).extract().body().asString());
    }

    @MessageBundle
    public interface MyNestedMessages {

        @Message("Hello {name}!")
        String hello_name(String name);

    }

    public static class TestRouteConfig {

        void addTestRoute(@Observes Router router) {
            router.route("/test")
                    .produces("text/plain")
                    .handler(rc -> rc.response().end(MessageBundles.get(MyNestedMessages.class).hello_name("Jachym")));
        }

    }

}
